==> rongcloud_im_plugin-0.0.7.tar.gz: example/lib/index.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'chat.dart';

import 'package:rongcloud_im_plugin/rongcloud_im_plugin.dart';
import 'package:rongcloud_im_plugin/rc_common_define.dart';

class IndexPage extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return new IndexState();
  }
}

class IndexState extends State<IndexPage> {
  /// create a channelController to retrieve text value
  final _channelController = TextEditingController();

  /// if channel textfield is validated to have error
  bool _validateError = false;

  @override
  void dispose() {
    // dispose input controller
    _channelController.dispose();
    super.dispose();
  }

  onPushPlatformView() {
    if(defaultTargetPlatform == TargetPlatform.iOS)  {
      Navigator.push(
      context,
      MaterialPageRoute(
        builder: (context) => new ChatPage(
          
        )));
    }else if(defaultTargetPlatform == TargetPlatform.android) {
      RongcloudImPlugin.pushToConversation(RCConversationType.Private, "afasdf");
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text('Flutter QuickStart'),
        ),
        body: Center(
          child: Container(
              padding: EdgeInsets.symmetric(horizontal: 20),
              height: 400,
              child: Column(
                children: <Widget>[
                  Padding(
                      padding: EdgeInsets.symmetric(vertical: 20),
                      child: Row(
                        children: <Widget>[
                          Expanded(
                            child: RaisedButton(
                              onPressed: () => onPushPlatformView(),
                              child: Text("onPushPlatformView"),
                              color: Colors.blueAccent,
                              textColor: Colors.white,
                            ),
                          )
                        ],
                      )
                    )
                ],
              )
              ),
        )
        );
  }

  onJoin() async {
    // update input validation
    setState(() {
      _channelController.text.isEmpty
          ? _validateError = true
          : _validateError = false;
    });
    if (_channelController.text.isNotEmpty) {
      // await for camera and mic permissions before pushing video page
      // push video page with given channel name
      Navigator.push(
          context,
          MaterialPageRoute(
              builder: (context) => new ChatPage(

                  )));
    }
  }


}

==> rongcloud_im_plugin-0.0.13.tar.gz: example/lib/index.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'chat.dart';

import 'package:rongcloud_im_plugin/rongcloud_im_plugin.dart';
import 'package:rongcloud_im_plugin/rc_common_define.dart';

class IndexPage extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return new IndexState();
  }
}

class IndexState extends State<IndexPage> {
  /// create a channelController to retrieve text value
  final _channelController = TextEditingController();

  /// if channel textfield is validated to have error
  bool _validateError = false;

  @override
  void dispose() {
    // dispose input controller
    _channelController.dispose();
    super.dispose();
  }

  onPushPlatformView() {
    if(defaultTargetPlatform == TargetPlatform.iOS)  {
      Navigator.push(
      context,
      MaterialPageRoute(
        builder: (context) => new ChatPage(
          
        )));
    }else if(defaultTargetPlatform == TargetPlatform.android) {
      // RongcloudImPlugin.pushToConversation(RCConversationType.Private, "afasdf");
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text('Flutter QuickStart'),
        ),
        body: Center(
          child: Container(
              padding: EdgeInsets.symmetric(horizontal: 20),
              height: 400,
              child: Column(
                children: <Widget>[
                  Padding(
                      padding: EdgeInsets.symmetric(vertical: 20),
                      child: Row(
                        children: <Widget>[
                          Expanded(
                            child: RaisedButton(
                              onPressed: () => onPushPlatformView(),
                              child: Text("onPushPlatformView"),
                              color: Colors.blueAccent,
                              textColor: Colors.white,
                            ),
                          )
                        ],
                      )
                    )
                ],
              )
              ),
        )
        );
  }

  onJoin() async {
    // update input validation
    setState(() {
      _channelController.text.isEmpty
          ? _validateError = true
          : _validateError = false;
    });
    if (_channelController.text.isNotEmpty) {
      // await for camera and mic permissions before pushing video page
      // push video page with given channel name
      Navigator.push(
          context,
          MaterialPageRoute(
              builder: (context) => new ChatPage(

                  )));
    }
  }


}
